#
# db2_secured::controls::audit_is_enabled_within_the_instance
#
# @summary Auditing is crucial for securing and discovering issues within your databases.
# Auditing can help trigger events for changes to data objects, table DML, and user access.
# 
# Rationale:
# 
# If instance auditing is not enabled, issues may go undiscovered, and compromises and other incidents may occur without being quickly detected. It may also not be possible to provide evidence of compliance with security laws, regulations, and other requirements.
# 
# paudit## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 7.1.4
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::audit_is_enabled_within_the_instance: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::audit_is_enabled_within_the_instance::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `audit_is_enabled_within_the_instance` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::audit_is_enabled_within_the_instance {
  $elements = $title.split('/')
  $instance = $elements[0]

  if  $facts['db2_instances'] {
    $home = $facts['db2_instances'][$instance]['dftdbpath']

    db2_secured_setup { "audit_is_enabled_within_the_instance on ${title}":
      ensure => 'present',
    }

    exec { 'Enable DB2 audit':
      command     => "${home}/sqllib/adm/db2audit start",
      unless      => "${home}/sqllib/adm/db2audit describe| /bin/grep 'Audit active: \"TRUE'",
      user        => $instance,
      environment => "DB2INSTANCE=${instance}",
    }
  } else {
    warning "Skipping this control until 'db2_instances' fact is filled"
  }
}
