#
# db2_secured::controls::database_manager_configuration_parameter_trust_allclnts
#
# @summary The `TRUST_ALLCLNTS` database manager configuration parameter is only active when the authentication parameter is set to `CLIENT` which is not a recommended setting as discussed in the authentication parameter section.
# If the parameter is set to `YES`, the server assumes that the client side is handling authentication to the database. If the parameter is set to `NO`, the client must provide authentication to the server on behalf of the user.
# 
# The recommended value for this parameter is `NO`.
# 
# Rationale:
# 
# If the server trusts the client to authenticate the connecting user, a malicious user can connect to the database as any user including a database administrator by simply creating that user on the client system.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 5.4
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::database_manager_configuration_parameter_trust_allclnts: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::database_manager_configuration_parameter_trust_allclnts::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `database_manager_configuration_parameter_trust_allclnts` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::database_manager_configuration_parameter_trust_allclnts {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "database_manager_configuration_parameter_trust_allclnts on ${title}":
    ensure => 'present',
  }

  if  $facts['db2_instances'] {
    if $facts['db2_instances'][$instance]['authentication'] == 'CLIENT' {
      resource_value { "Db2_instance[${instance}]trust_allclnts":
        allow_create   => true,
        allow_redefine => true,
        value          => 'NO',
      }
    } else {
      debug 'database_manager_configuration_parameter_trust_allclnts skipped because not relevant'
    }
  } else {
    warning "Skipping this control until 'db2_instances' fact is filled"
  }
}
