#
# db2_secured::controls::disable_datalinks_support
#
# @summary Datalinks enables the database to support the Data Links Manager to manage unstructured data, such as images, large files and other unstructured files on the host.
# It is recommended that datalinks support be disabled.
# 
# Rationale:
# 
# Disable datalinks if there is no use for them as this will reduce the attack surface of the DB2 service.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.4
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::disable_datalinks_support: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::disable_datalinks_support::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `disable_datalinks_support` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::disable_datalinks_support {
  $elements = $title.split('/')
  $instance = $elements[0]

  $major_version = Integer($facts['db2_instances'][$instance]['version'].split('\.')[0])

  # lint:ignore:version_comparison
  if $major_version < 11 {
    db2_secured_setup { "disable_datalinks_support on ${title}":
      ensure => 'present',
    }

    resource_value { "Db2_instance[${instance}]datalinks":
      allow_create   => true,
      allow_redefine => true,
      value          => 'NO',
    }
  } else {
    alert("On DB2 version 11 and higher datalinks setting not supported. control skipped for ${title}")
  }
  # lint:endignore:version_comparison
}
