#
# db2_secured::controls::disable_grants_during_restore
#
# @summary he `DB2_RESTORE_GRANT_ADMIN_AUTHORITIES` registry variable determines whether the authorization ID of the user performing a restore is granted administrative authorities (`SECADM`, `DBADM`, `DATAACCESS`, and `ACCESSCTRL` authorities) on the restored database.
# It is typically used when restoring a database on a server where the original database creator account does not exist. It is recommended that this variable not be set except when specifically performing a restore where you wish these privileges to be granted so they are not accidentally granted.
# 
# Rationale:
# 
# Use of this registry variable may grant administrative authorities accidentally if the value is left on during normal operations and a restore is run.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 3.2.3
# - [DB2 Database 11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.2.3
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::disable_grants_during_restore: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::disable_grants_during_restore::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `disable_grants_during_restore` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::disable_grants_during_restore {
  db2_secured_setup { "disable_grants_during_restore on ${title}":
    ensure => 'present',
  }

  -> db2_secured::internal::ensure_registry_value { "${title}/DB2_RESTORE_GRANT_ADMIN_AUTHORITIES":
    value => 'OFF',
  }
}
