#
# db2_secured::controls::disable_limited_audit_of_applications
#
# @summary The `DB2_LIMIT_AUDIT_APPS` registry variable contains a list of application names that should not be audited.
# It is recommended that this variable should not be set and all applications should be audited.
# 
# The `DB2_LIMIT_AUDIT_APPS` registry variable is not documented.
# 
# Rationale:
# 
# The application name not to be audited is determined by the client and not validated by the server. It is possible for a malicious user to change their application name to avoid being audited.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 7.1.2
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::disable_limited_audit_of_applications: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::disable_limited_audit_of_applications::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `disable_limited_audit_of_applications` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::disable_limited_audit_of_applications {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]
  $key      = $elements[2]

  if  $facts['db2_instances'] {
    $home     = $facts['db2_instances'][$instance]['dftdbpath']

    db2_secured_setup { "disable_limited_audit_of_applications on ${title}":
      ensure => 'present',
    }

    -> exec { 'Set registry value for DB2_LIMIT_AUDIT_APP':
      command     => "${home}/sqllib/adm/db2set DB2_LIMIT_AUDIT_APPS=",
      onlyif      => "${home}/sqllib/adm/db2set -all | /usr/bin/grep -e 'DB2_LIMIT_AUDIT_APPS='",
      user        => $instance,
      environment => "DB2INSTANCE=${instance}",
    }
  } else {
    warning "Skipping this control until 'db2_instances' fact is filled"
  }
}
