#
# db2_secured::controls::enable_extended_security
#
# @summary The `DB2_EXTSECURITY` registry variable determines whether extended security is enabled on Windows.
# Extended security enables file permissions for all Db2 objects so they can be accessed by users in `DB2ADMNS` and `DB2USERS` groups. It is recommended that extended security be enabled.
# This registry variable only applies to Db2 Servers running on Windows.
# 
# Rationale:
# 
# Extended security provides file permission protection for Db2 objects when running in a multi-user environment.
# 
# Impact:
# 
# Before enabling extended security for an existing installation, you should ensure you have added users to the `DB2ADMNS` and `DB2USERS` groups so that you are able to access Db2 once the permission have been applied. Once extended security is enabled, it is not recommended to be directly disabled, instead a full re-install should be used.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.2.4
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::enable_extended_security: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::enable_extended_security::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `enable_extended_security` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::enable_extended_security {
  db2_secured_setup { "enable_extended_security on ${title}":
    ensure => 'present',
  }
  if $facts['kernel'] == 'Windows' {
    alert('Specified CIS control is not yet automatically enforced.')
  } else {
    debug('Specified CIS control is not applicable on current kernel')
  }
}
