#
# db2_secured::controls::require_explicit_authorization_for_cataloging
#
# @summary DB2 can be configured to allow users that do not possess the `SYSADM` authority to catalog and uncatalog databases and nodes.
# It is recommended that the `catalog_noauth` parameter be set to `NO`.
# 
# Rationale:
# 
# Cataloging a database is the process of registering a database from a remote client to allow remote call and access. Setting `catalog_noauth` to `YES` bypasses all permissions checks and allows anyone to catalog and uncatalog databases.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.3
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 3.1.1
# - [DB2 Database 11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.1.1
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::require_explicit_authorization_for_cataloging: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::require_explicit_authorization_for_cataloging::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `require_explicit_authorization_for_cataloging` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::require_explicit_authorization_for_cataloging {
  $elements = $title.split('/')
  $instance = $elements[0]

  db2_secured_setup { "require_explicit_authorization_for_cataloging on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_instance[${instance}]catalog_noauth":
    allow_create   => true,
    allow_redefine => true,
    value          => 'NO',
  }
}
