#
# db2_secured::controls::secure_permissions_for_all_diagnostic_logs
#
# @summary The `diagpath` parameter specifies the location of the diagnostic files for the DB2 instance.
# The directory at this location should be secured so that users have read and execute privileges only (no write privileges). All DB2 administrators should have full access to the directory.
# 
# Rationale:
# 
# Securing the directory will ensure that the confidentiality, integrity, and availability of the diagnostic files contained in the directory are preserved.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.7
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 3.1.4
# - [DB2 Database 11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.1.4
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::secure_permissions_for_all_diagnostic_logs: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::secure_permissions_for_all_diagnostic_logs::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `secure_permissions_for_all_diagnostic_logs` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::secure_permissions_for_all_diagnostic_logs {
  $elements = $title.split('/')
  $instance = $elements[0]

  if  $facts['db2_instances'] {
    $diag_path  = $facts['db2_instances'][$instance]['diagpath'].split(' ')[0]

    db2_secured_setup { "secure_permissions_for_all_diagnostic_logs on ${title}":
      ensure => 'present',
    }

    # lint:ignore:recurse_file
    -> file { $diag_path:
      mode    => '0755',
      recurse => true,
    }
    # lint:endignore:recurse_file
  } else {
    warning "Skipping this control until 'db2_instances' fact is filled"
  }
}
