#
# db2_secured::controls::secure_permissions_for_the_log_overflow_location
#
# @summary The `overflowlogpath` parameter specifies a location for Db2® databases to find log files needed for a rollforward operation, as well as where to store active log files retrieved from the archive.
# It also gives a location for finding and storing log files needed for using db2ReadLog API. It is recommended that the directory used be set to full access for Db2 administrator accounts and read and execute only for all other accounts.
# 
# Rationale:
# 
# The overflow log path can contain log files containing user data. Access to the directory pointed to by that path should be restricted through permissions to help ensure that the confidentiality, integrity, and availability of the logs are protected.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 4.1.9
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::secure_permissions_for_the_log_overflow_location: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::secure_permissions_for_the_log_overflow_location::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `secure_permissions_for_the_log_overflow_location` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::secure_permissions_for_the_log_overflow_location {

  if  $facts['db2_databases'] {
    $overflow_log_path  = $facts['db2_databases'][$title]['overflowlogpath']

    db2_secured_setup { "secure_permissions_for_the_log_overflow_location on ${title}":
      ensure => 'present',
    }

    # lint:ignore:recurse_file
    if $overflow_log_path != undef {
      file { $overflow_log_path:
        mode    => '0755',
        recurse => true,
      }
    }
    # lint:endignore:recurse_file
  } else {
    warning "Skipping this control until 'db2_databases' fact is filled"
  }
}
