#
# db2_secured::controls::secure_permissions_for_the_secondary_archive_log_location
#
# @summary The `logarchmeth2` parameter specifies the type of media and the location used as the secondary destination for archived logs.
# It is recommended that the directory used for the archived logs be set to full access for DB2 administrator accounts and read and execute only for all other accounts.
# 
# Rationale:
# 
# Restricting access to the contents of the secondary archive log directory will help ensure that the confidentiality, integrity, and availability of archive logs are protected.
# Although there are many ways to ensure that your logs will be archived, we recommend using the value of DISK as part of the `logarchmeth2` parameter. This will properly ensure that the logs are archived. A finding of `OFF` is not acceptable.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.18
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 4.1.6
# - [DB2 Database 11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 4.1.6
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::secure_permissions_for_the_secondary_archive_log_location: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::secure_permissions_for_the_secondary_archive_log_location::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `secure_permissions_for_the_secondary_archive_log_location` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::secure_permissions_for_the_secondary_archive_log_location (
  Optional[Stdlib::Absolutepath] $preferred_value = undef,
) {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]
  $home     = $facts['db2_instances'][$instance]['dftdbpath']

  if $preferred_value == undef {
    $requested_value = db2_secured::lookup_setting('preferred_value', "${home}/archives/archive_2/")
  } else {
    $requested_value = $preferred_value
  }

  db2_secured_setup { "secure_permissions_for_the_secondary_archive_log_location on ${title}":
    ensure => 'present',
  }

  -> db2_secured::internal::archive_directory { "${title}/logarchmeth2":
    path      => $requested_value,
  }
}
