#
# db2_secured::controls::secure_the_communication_buffer_exit_library
#
# @summary A communication exit library is a dynamically loaded library that vendor applications use to examine communication buffers.
# The `comm_exit_list` parameter specifies the list of communication buffer exist libraries. The permissions on the libraries should be secured so that users other than the instance owner do not have write privileges.
# 
# Rationale:
# 
# If a malicious user has write access to a communication exit library, they can overwrite it with their own thereby receiving all of the communication buffers that Db2 receives over the network. Securing the libraries will prevent a loss of confidentiality of data.
# 
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 3.1.13
# - [DB2 Database 11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.1.13
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::secure_the_communication_buffer_exit_library: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::secure_the_communication_buffer_exit_library::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `secure_the_communication_buffer_exit_library` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::secure_the_communication_buffer_exit_library {
  $elements = $title.split('/')
  $instance = $elements[0]
  if  $facts['db2_instances'] {
    $home     = $facts['db2_instances'][$instance]['dftdbpath']

    db2_secured_setup { "secure_the_communication_buffer_exit_library on ${title}":
      ensure => 'present',
    }

    # lint:ignore:recurse_file
    file { ["${home}/security32/plugin/commexit", "${home}/security64/plugin/commexit"]:
      mode    => '0755',
      recurse => true,
      require => Db2_secured_setup["secure_the_communication_buffer_exit_library on ${title}"],
    }
    # lint:endignore:recurse_file
  } else {
    warning "Skipping this control until 'db2_instances' fact is filled"
  }
}
