#
# db2_secured::controls::secure_the_r_runtime_path
#
# @summary The `r_path` parameter contains the directory under which the R runtime is installed.
# The R runtime is used for running R stored procedures and user-defined functions. It is recommended that the owner of this directory is bin on Linux and AIX, and a member of the Db2 administration group on Windows. The directory should have read and execute permission for all users, but only write permission for the owner.
# 
# Rationale:
# 
# Restricting access to the R runtime will help ensure that only an authorized runtime is used for running R routines within Db2.
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 3.1.12
# - [DB2 Database 11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.1.12
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::secure_the_r_runtime_path: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::secure_the_r_runtime_path::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `secure_the_r_runtime_path` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::secure_the_r_runtime_path {
  $elements = $title.split('/')
  $instance = $elements[0]

  if  $facts['db2_instances'] {
    $r_path   = $facts['db2_instances'][$instance]['r_path']

    db2_secured_setup { "secure_the_r_runtime_path on ${title}":
      ensure => 'present',
    }

    # lint:ignore:recurse_file
    if $r_path != undef {
      file { $r_path:
        mode    => '0755',
        recurse => true,
        require => Db2_secured_setup["secure_the_r_runtime_path on ${title}"],
      }
    }
    # lint:endignore:recurse_file
  } else {
    warning "Skipping this control until 'db2_instances' fact is filled"
  }
}
