#
# db2_secured::controls::set_diagnostic_logging_to_capture_errors_and_warnings
#
# @summary The `diaglevel` parameter specifies the type of diagnostic errors that will be recorded in the `db2diag.
# log` file. It is recommended that the `diaglevel` parameter be set to at least 3.
# 
# Rationale:
# 
# The recommended `diaglevel` setting is 3, but any value greater than 3 is also acceptable. A value of at least 3 will allow the DB2 instance to capture all errors and warnings that occur on the system.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.6
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 3.1.3
# - [DB2 Database 11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.1.3
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::set_diagnostic_logging_to_capture_errors_and_warnings: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::set_diagnostic_logging_to_capture_errors_and_warnings::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `set_diagnostic_logging_to_capture_errors_and_warnings` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::set_diagnostic_logging_to_capture_errors_and_warnings (
  Integer[3] $preferred_value = db2_secured::lookup_setting('preferred_value', 3),
) {
  $elements = $title.split('/')
  $instance = $elements[0]

  db2_secured_setup { "set_diagnostic_logging_to_capture_errors_and_warnings on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_instance[${instance}]diaglevel":
    allow_create   => true,
    allow_redefine => true,
    value          => $preferred_value,
  }
}
