#
# db2_secured::controls::set_maximum_connection_limits
#
# @summary The `max_connections` parameter indicates the maximum number of client connections allowed per database partition.
# It is recommended that this parameter be set equal to the `max_coordagents` parameter. The `max_coordagents` parameter equals the maximum number of agents needed to perform connections to the database or attachments to the instance.
# NOTE: Ensure that dependent parameters, such as maxappls, are set less than the `max_coordagents` parameter. This would ensure that the lock limit isn't reached, which would result in lock escalation issues.
# 
# Rationale:
# 
# By default, DB2 allows an unlimited number of users to access the DB2 instance. In addition to giving access to the DB2 instance to authorized users only, it is recommended to set a limit to the number of users allowed to access a DB2 instance. This helps prevent denial of service conditions should an authorized process malfunction and attempt a large number of simultaneous connections.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.1.11
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::set_maximum_connection_limits: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::set_maximum_connection_limits::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `set_maximum_connection_limits` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::set_maximum_connection_limits (
  Integer $preferred_value = db2_secured::lookup_setting('preferred_value', 100),
) {
  $elements = $title.split('/')
  $instance = $elements[0]
  $lower_value = $preferred_value -1

  db2_secured_setup { "set_maximum_connection_limits on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_instance[${instance}]max_coordagents":
    allow_create   => true,
    allow_redefine => true,
    value          => "AUTOMATIC(${preferred_value})",
  }
  # TODO: Look at the maxappl settings
  # resource_value { "Db2_instance[${instance}]maxappls":
  #   allow_create => true,
  #   value        => ${lower_value},
  # }
}
