#
# db2_secured::controls::set_maximum_number_of_applications
#
# @summary he `maxappls` parameter specifies the maximum number of concurrent applications that can be connected (both local and remote) to a database.
# In an instance with a single database, it is recommended that this value be set to `AUTOMATIC`. While this indicates that any number of connections should be allowed, an upper limit of `max_connections` database manager configuration parameter is still enforced. If there are multiple databases within the instance, then the sum of `maxappls` for each database should be less than or equal to `max_connections`.
# 
# When `AUTOMATIC` is used, `maxappls` can also have a parameter. The value is not used to determine the maximum number of connections, but rather for dependent parameters, such as pckcachesz and catalog_cachesz that can derive their value from `maxappls`. In such a case the value specified with `AUTOMATIC` should represent the expected number of connections.
# 
# Rationale:
# 
# By default, Db2 allows an unlimited number of users to access the Db2 instance. In addition to giving access to the Db2 instance to authorized users only, it is recommended to set a limit to the number of users allowed to access a Db2 instance. This helps prevent denial of service conditions should an authorized process malfunction and attempt many simultaneous connections.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 4.1.12
# - [DB2 Database 11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 4.1.12
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::set_maximum_number_of_applications: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::set_maximum_number_of_applications::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `set_maximum_number_of_applications` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::set_maximum_number_of_applications (
  Variant[String[1], Integer] $preferred_value = db2_secured::lookup_setting('preferred_value', '200'),
) {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "set_maximum_number_of_applications on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_database[${title}]maxappls":
    allow_create   => true,
    allow_redefine => true,
    value          => $preferred_value,
  }
}
