#
# db2_secured::controls::specify_a_secure_connection_authentication_type
#
# @summary The `SRVCON_AUTH` database manager configuration parameter specifies how and where authentication takes place for incoming connections to the database.
# This parameter overrides the AUTHENTICATION parameter.
# 
# This parameter can take on any of the following values:
# 
# - `NOT_SPECIFIED`
# - `CLIENT`
# - `SERVER`
# - `SERVER_ENCRYPT`
# - `KERBEROS`
# - `KRB_SERVER_ENCRYPT`
# - `GSSPLUGIN`
# - `GSS_SERVER_ENCRYPT`
# - `SERVER_ENCRYPT_TOKEN`
# - `KERBEROS_TOKEN`
# - `GSSPLUGIN_TOKEN`
# - `KRB_SVR_ENC_TOKEN`
# - `GSS_SVR_ENC_TOKEN`
# 
# If this parameter is set to `NOT_SPECIFIED`, then the type of authentication for connections is determined by the `AUTHENTICATION` parameter.
# 
# Recommendations:
# 
# Do not use `CLIENT` authentication type.
# 
# `SERVER_ENCRYPT` instead of `SERVER` is recommended as a compensating configuration if TLS cannot be used to encrypted client server communications.
# 
# Rationale:
# 
# When using `CLIENT` authentication type, the server trusts the client to authenticate the connecting user. A malicious user can connect to the database as any user including a database administrator by simply creating that user on the client system.
# 
# When using `SERVER` authentication type without SSL enabled, the user ID and password that are sent from the client to the server during a connect or an attach are in plaintext format. Therefore, these credentials are exposed when sent across an unsecure network and can be intercepted by a malicious user.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 5.1
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::specify_a_secure_connection_authentication_type: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::specify_a_secure_connection_authentication_type::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `specify_a_secure_connection_authentication_type` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::specify_a_secure_connection_authentication_type {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "specify_a_secure_connection_authentication_type on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_instance[${instance}]srvcon_auth/4":
    allow_create   => true,
    allow_redefine => true,
    value          => 'SERVER_ENCRYPT',
  }
}
