#
# db2_secured::controls::specify_secure_remote_shell_command
#
# @summary The `db2rshcmd` registry varible specifies the remote shell command to use when starting remote database partitions and with the db2_all script to run utilities and commands on all database partitions.
# It is recommended that a value be used which encrypts the data sent between partitions, such as ssh.
# 
# Rationale:
# 
# The traditional rsh command sends all its data, including passwords, in plaintext between partitions. An attacker who can read network traffic may have access to these passwords and other data. Specifying a remote shell command, such as ssh encrypts the data sent over the network.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 11 CIS V1.0.0.draft](/docs/db2_secured/cis/db11_V1.0.0.draft.html) - paragraph 3.2.1
# - [DB2 Database 11 CIS V1.0.0](/docs/db2_secured/cis/db11_V1.0.0.html) - paragraph 3.2.1
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::specify_secure_remote_shell_command: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::specify_secure_remote_shell_command::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `specify_secure_remote_shell_command` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::specify_secure_remote_shell_command {
  db2_secured_setup { "specify_secure_remote_shell_command on ${title}":
    ensure => 'present',
  }

  -> db2_secured::internal::ensure_registry_value { "${title}/DB2RSHCMD":
    value => 'ssh',
  }
}
