#
# db2_secured::controls::ssl_service_name_ssl_svcename
#
# @summary The `ssl_svcename` configuration parameter defines the name or number of the port the database server listens for communications from remote client nodes using SSL protocol.
# The `ssl_svcename` and the svcename port numbers cannot be the same.
# On Linux operating systems, the `ssl_svcename` file is located in: /etc/services
# 
# Rationale:
# 
# The database requires a defined port to listen for incoming remote clients using the SSL protocol. The `ssl_svcename` configuration parameter defines the port for communicating with remote clients.
# Consider using a non-default port to help protect the database from attacks directed to a default port.
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.2.2
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::ssl_service_name_ssl_svcename: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::ssl_service_name_ssl_svcename::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `ssl_service_name_ssl_svcename` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::ssl_service_name_ssl_svcename (
  Variant[String[1], Integer] $preferred_value = db2_secured::lookup_setting('preferred_value', 70000),
) {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "ssl_service_name_ssl_svcename on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_instance[${instance}]ssl_svcename":
    allow_create   => true,
    allow_redefine => true,
    value          => $preferred_value,
  }
}
