#
# db2_secured::controls::tcp_ip_service_name_svcename
#
# @summary The `svcename` parameter reserves the port number (or name, on Linux hosts) for listening to incoming communications from a Data Server Runtime Client.
# Both the database server port number or name and the TCP/IP service name must be defined on the database client.
# 
# Rationale:
# 
# When the database server is started, a port number or name is required to listen for incoming connection requests. The `svcename` parameter defines the port number or name for incoming connection requests. On Linux systems, the services file is found at: /etc/services
# 
# ## Excelent Compliance Solution.
# 
# Puppet is an excellent solution to ensure your databases are CIS or STIG compliant. 
# Now you're looking at information about only one compliance control, but managing total compliance isn't hard either! 
# 
# If you you like he prospect of easy way into continuous compliancy with minimal fuss and bother, we suggest
# taking a look at [our solution](/docs/db2_secured/description.html) as your go-to option. 
# Plus, our team can help you get up and running so that you can focus on other 
# areas of your business. What are you waiting for? [Get started today!](/company/contact/)
# 
# ## Benchmarks
# 
# This control is used in the following benchmarks:
# 
# - [DB2 Database 10 CIS V1.1.0](/docs/db2_secured/cis/db10_V1.1.0.html) - paragraph 3.2.1
# 
# 
# ## Skipping
# 
# To deliberately skip this control (e.g. meaning don't use Puppet to enforce this setting), we provide
# you with three ways:
# 
# 1) Add `db2_secured::controls::tcp_ip_service_name_svcename: skip` to your hiera data. This will skip this control for **ALL** databases.  
# 2) Add `db2_secured::controls::tcp_ip_service_name_svcename::instance_name::dbname: skip` to your hiera data. This will skip this control for specified database only.  
# 3) Add an entry with the content `tcp_ip_service_name_svcename` to the array value `db2_secured::skip_list` in your hiera data.
#
# @param title
#    The database identifier to apply the control to.
#    All controls need an database identifier to apply the control to. Here is a simple example:
#    ``` puppet
#    db2_secured::controls::control_name { 'db2inst1/MYDB':}
#    ```
#    In this example, the string `dbinst1` is the instance, the string `MYDB` is the database to apply the control to.
#
#
# See the file "LICENSE" for the full license governing this code.
#
define db2_secured::controls::tcp_ip_service_name_svcename (
  Variant[String[1], Integer] $preferred_value = db2_secured::lookup_setting('preferred_value', 60000),
) {
  $elements = $title.split('/')
  $instance = $elements[0]
  $database = $elements[1]

  db2_secured_setup { "tcp_ip_service_name_svcename on ${title}":
    ensure => 'present',
  }

  resource_value { "Db2_instance[${instance}]svcename":
    allow_create   => true,
    allow_redefine => true,
    value          => $preferred_value,
  }
}
